@@ -74,7 +74,7 @@ from . import util
 from . import validation
 
 from .amqp import AMQP
-from .api import Api, OAuthApi, OAuth1Api, OAuth2Api
+from .api import API, OAuthAPI, OAuth1API, OAuth2API
 from .asynchronous import ASYNC_HEADER, AsyncManager, SimpleManager, QueueManager, AwaitWrapper, CoroutineWrapper,\
     AyncgenWrapper, await_wrap, await_yield, ensure_generator, is_coroutine, is_coroutine_object, is_coroutine_native,\
     to_coroutine, wrap_silent, unavailable, is_neo, Future, coroutine, wakeup, sleep, wait, notify, build_future,\
@@ -116,12 +116,12 @@ from .settings import DEBUG, USERNAME, PASSWORD
 from .smtp import message, message_base, message_netius, smtp_engine, multipart, plain,\
     html, header
 from .storage import StorageEngine, BaseEngine, FsEngine
-from .structures import OrderedDict
+from .structures import OrderedDict, LazyDict, LazyValue, lazy_dict, lazy
 from .typesf import AbstractType, Type, File, Files, ImageFile, ImageFiles, image, images, Reference,\
     reference, References, references, Encrypted, encrypted, secure
 from .util import is_iterable, is_mobile, is_tablet, email_parts, email_mime, email_name, email_base,\
     date_to_timestamp, obfuscate, import_pip, ensure_pip, install_pip, install_pip_s, request_json,\
-    get_object, resolve_alias, page_types, find_types, norm_object, set_object, leafs, gen_token,\
+    get_object, resolve_alias, page_types, find_types, norm_object, set_object, leafs, gather_errors, gen_token,\
     html_to_text, camel_to_underscore, camel_to_readable, underscore_to_readable, quote, unquote,\
     call_safe, base_name, base_name_m, is_content_type, parse_content_type, parse_cookie, parse_multipart,\
     decode_params, load_form, check_login, check_token, check_tokens, ensure_login, get_tokens_m, to_tokens_m,\
