@@ -37,7 +37,9 @@ __copyright__ = "Copyright (c) 2008-2017 Hive Solutions Lda."
 __license__ = "Apache License, Version 2.0"
 """ The license for the module """
 
+import calendar
 import unittest
+import datetime
 
 import appier
 
@@ -216,3 +218,60 @@ class TypesfTest(unittest.TestCase):
 
         self.assertEqual(type(result), int)
         self.assertEqual(result, 3)
+
+    def test_custom(self):
+
+        class DateTime(appier.Type):
+
+            def loads(self, value):
+                cls = self.__class__
+                if isinstance(value, cls):
+                    self._datetime = value._datetime
+                elif isinstance(value, datetime.datetime):
+                    self._datetime = value
+                elif isinstance(value, (int, float)):
+                    self._datetime = datetime.datetime.utcfromtimestamp(value)
+                else:
+                    raise appier.OperationalError()
+
+            def dumps(self):
+                return self.timestamp()
+
+            def timestamp(self):
+                return calendar.timegm(self._datetime.utctimetuple())
+
+        class CustomPerson(mock.Person):
+
+            birth = appier.field(
+                type = DateTime
+            )
+
+        self.app._register_model(CustomPerson)
+
+        person = CustomPerson()
+        person.name = "Name"
+        person.birth = DateTime(0)
+        person.save()
+
+        self.assertEqual(person.name, "Name")
+        self.assertEqual(type(person.birth), DateTime)
+        self.assertEqual(person.birth.timestamp(), 0)
+
+        person = CustomPerson.get(name = "Name")
+
+        self.assertEqual(person.name, "Name")
+        self.assertEqual(type(person.birth), DateTime)
+        self.assertEqual(person.birth.timestamp(), 0)
+
+        person = CustomPerson(name = "New Name", birth = 1)
+        person.save()
+
+        self.assertEqual(person.name, "New Name")
+        self.assertEqual(type(person.birth), DateTime)
+        self.assertEqual(person.birth.timestamp(), 1)
+
+        person = CustomPerson.get(birth = 1)
+
+        self.assertEqual(person.name, "New Name")
+        self.assertEqual(type(person.birth), DateTime)
+        self.assertEqual(person.birth.timestamp(), 1)
