@@ -318,6 +318,7 @@ class ImageFile(File):
         self.width = file_m.get("width", 0)
         self.height = file_m.get("height", 0)
         self.format = file_m.get("format", None)
+        self.kwargs = file_m.get("kwargs", {})
         self._ensure_all()
 
     def build_t(self, file_t):
@@ -329,6 +330,7 @@ class ImageFile(File):
         self.width = file.width if hasattr(file, "width") else 0
         self.height = file.height if hasattr(file, "height") else 0
         self.format = file.format if hasattr(file, "format") else None
+        self.kwargs = file.kwargs if hasattr(file, "kwargs") else {}
         self._ensure_all()
 
     def build_f(self, file):
@@ -341,13 +343,15 @@ class ImageFile(File):
         value.update(
             width = self.width,
             height = self.height,
-            format = self.format
+            format = self.format,
+            kwargs = self.kwargs
         )
         return value
 
     def _ensure_all(self):
         self._ensure_size()
         self._ensure_mime()
+        self._ensure_kwargs()
 
     def _ensure_size(self):
         if hasattr(self, "width") and self.width and\
@@ -359,6 +363,10 @@ class ImageFile(File):
             hasattr(self, "mime") and self.mime: return
         self.format, self.mime = self._mime()
 
+    def _ensure_kwargs(self):
+        if hasattr(self, "kwargs"): return
+        self.kwargs = dict()
+
     def _size(self):
         try: return self._size_image()
         except: return self._size_default()
@@ -409,10 +417,14 @@ class ImageFiles(Files):
     def base(self):
         return ImageFile
 
-def image(width = None, height = None, format = "png"):
+def image(width = None, height = None, format = "png", **kwargs):
 
     class _ImageFile(ImageFile):
 
+        RGB_FORMATS = ("jpg", "jpeg")
+        """ The set of format that are considered to be
+        RGB based and should be handled with special care """
+
         def build_b64(self, file_m):
             ImageFile.build_b64(self, file_m)
 
@@ -427,7 +439,8 @@ def image(width = None, height = None, format = "png"):
             need_resize = self.need_resize(
                 width_o = self.width,
                 height_o = self.height,
-                format_o = self.format
+                format_o = self.format,
+                kwargs_o = self.kwargs
             )
             if not need_resize: return
 
@@ -446,6 +459,10 @@ def image(width = None, height = None, format = "png"):
             # width, height and format from the original one
             file_m["data"] = data_b64
 
+            # updates the parameters attributes in the file map so
+            # that the new file is marked with proper values
+            file_m["kwargs"] = kwargs
+
             # removes a series of keys from the file map as
             # they are no longer reliable and may reflect
             # different values from the ones contained in data
@@ -453,6 +470,8 @@ def image(width = None, height = None, format = "png"):
             for name in ("width", "height", "format"):
                 if name in file_m: del file_m[name]
 
+            # runs the rebuilding of the information taking into
+            # account the new information from the file
             ImageFile.build_b64(self, file_m)
 
         def build_t(self, file_t):
@@ -465,6 +484,10 @@ def image(width = None, height = None, format = "png"):
             try: _data = self.resize(data) if data else data
             except: _data = data
 
+            # updates the parameters attributes in the instance so
+            # that the new file is marked with proper values
+            self.kwargs = kwargs
+
             # creates the "new" file tuple with the newly resized
             # image data and runs the parent tuple build method
             file_t = (name, content_type, _data)
@@ -480,13 +503,17 @@ def image(width = None, height = None, format = "png"):
             is_resized = True if width or height else False
             if not is_resized: return data
 
+            params = kwargs.get("params", {})
+            background = kwargs.get("background", "ffffff")
+
             size = (width, height)
             in_buffer = legacy.BytesIO(data)
             out_buffer = legacy.BytesIO()
             try:
                 image = PIL.Image.open(in_buffer)
                 image = self._resize(image, size)
-                image.save(out_buffer, format)
+                image = self._format(image, format, background)
+                image.save(out_buffer, format, **params)
                 data = out_buffer.getvalue()
             finally:
                 in_buffer.close()
@@ -498,11 +525,13 @@ def image(width = None, height = None, format = "png"):
             self,
             width_o = None,
             height_o = None,
-            format_o = None
+            format_o = None,
+            kwargs_o = None
         ):
             if width and not width == width_o: return True
             if height and not height == height_o: return True
             if format and not format == format_o: return True
+            if kwargs and not kwargs == kwargs_o: return True
             return False
 
         def _resize(self, image, size):
@@ -555,14 +584,40 @@ def image(width = None, height = None, format = "png"):
             image = image.resize(size, PIL.Image.ANTIALIAS)
             return image
 
+        def _format(self, image, format, background):
+            util.ensure_pip("PIL", package = "pillow")
+            import PIL.Image
+
+            # retrieves the reference to the top level class that is
+            # going to be used for the access to some of the values
+            cls = self.__class__
+
+            # converts the target format into the lower based version
+            # (normalization) and verifies if it's considered to be
+            # an RGB only format, if that's not the case there's nothing
+            # remaining to be done (no conversion required)
+            format = format.lower()
+            if not format in cls.RGB_FORMATS: return image
+
+            # in case the format/mode of the original image is already
+            # RGB there's no need to run the conversion process
+            if image.mode == "RGB": return image
+
+            # creates a new RGB based image with the target size and
+            # with the provided background and copies it as the target
+            new = PIL.Image.new("RGB", (image.width, image.height), "#" + background)
+            new.paste(image, image)
+            return new
+
     return _ImageFile
 
-def images(width = None, height = None, format = "png"):
+def images(width = None, height = None, format = "png", **kwargs):
 
     image_c = image(
         width = width,
         height = height,
-        format = format
+        format = format,
+        **kwargs
     )
 
     class _ImageFiles(ImageFiles):
