@@ -110,6 +110,7 @@ def to_sort(sort_s):
     return [tuple(values)]
 
 ALIAS = {
+    "context" : "find_d",
     "filters" : "find_d",
     "filters[]" : "find_d",
     "filter_def" : "find_d",
@@ -560,6 +561,41 @@ def leafs(object):
     # to the caller method so that it may be used there
     return leafs_l
 
+def gather_errors(lazy_dict, resolve = True):
+    """
+    Function responsible for the iterative gathering of
+    lazy evaluation errors, allowing for a complete gathering
+    of error instead of a single evaluation.
+
+    :type lazy_dict: LazyDict
+    :param lazy_dict: The lazy dictionary that is going to be
+    percolated and evaluated sequentially.
+    :type resolve: bool
+    :param resolve: If the lazy dictionary values should be evaluated
+    even if they have already been eager loaded, by unsetting this value
+    there's a risk of not gathering all of the errors.
+    :rtype: Dictionary
+    :return: The final dictionary containing the complete set of
+    errors that have been found.
+    """
+
+    # creates the dictionary that is going to hold sequences of
+    # string based error indexed by parameter name
+    errors = dict()
+
+    # iterates over the complete set of keys in the lazy dictionary
+    # to evaluate the values and check if there are errors associated
+    for key in lazy_dict:
+        try: _value = lazy_dict.__getitem__(key, resolve = resolve)
+        except exceptions.AppierException as exception:
+            _errors = errors.get(key, [])
+            _errors.append(exception.message)
+            errors[key] = _errors
+
+    # returns the final dictionary of error (indexed by name) to
+    # the caller method so that it may be used for error handling
+    return errors
+
 def gen_token(limit = None, hash = hashlib.sha256):
     """
     Generates a random cryptographic ready token according
@@ -589,7 +625,7 @@ def gen_token(limit = None, hash = hashlib.sha256):
 
 def html_to_text(data):
     """
-    Converts the provided html textual data into a plain text
+    Converts the provided HTML textual data into a plain text
     representation of it. This method uses a series of heuristics
     for this conversion, and such conversion should not be considered
     to be completely reliable.
@@ -598,11 +634,11 @@ def html_to_text(data):
     and should be used carefully to avoid performance problems.
 
     :type data: String
-    :param data: The html string of text that is going to be used for
+    :param data: The HTML string of text that is going to be used for
     the conversion into the plain text representation.
     :rtype: String
     :return: The approximate plain text representation to the provided
-    html contents.
+    HTML contents.
     """
 
     data = data.strip()
@@ -711,17 +747,17 @@ def underscore_to_readable(underscore, capitalize = False):
 def quote(value, *args, **kwargs):
     """
     Quotes the passed value according to the defined
-    standard for url escaping, the value is first encoded
+    standard for URL escaping, the value is first encoded
     into the expected utf-8 encoding as defined by standard.
 
     This method should be used instead of a direct call to
-    the equivalent call in the url library.
+    the equivalent call in the URL library.
 
     :type value: String
     :param value: The string value that is going to be quoted
-    according to the url escaping scheme.
+    according to the URL escaping scheme.
     :rtype: String
-    :return: The quoted value according to the url scheme this
+    :return: The quoted value according to the URL scheme this
     value may be safely used in urls.
     """
 
@@ -731,17 +767,17 @@ def quote(value, *args, **kwargs):
 
 def unquote(value, *args, **kwargs):
     """
-    Unquotes the provided value according to the url scheme
+    Unquotes the provided value according to the URL scheme
     the resulting value should be an unicode string representing
     the same value, the intermediary string value from the decoding
     should be an utf-8 based value.
 
     This method should be used instead of a direct call to
-    the equivalent call in the url library.
+    the equivalent call in the URL library.
 
     :type value: String
     :param value: The string value that is going to be unquoted
-    according to the url escaping scheme.
+    according to the URL escaping scheme.
     :rtype: String
     :return: The unquoted value extracted as an unicode
     string that the represents the same value.
@@ -1526,12 +1562,13 @@ def sanitize(function, kwargs):
         removal.append(name)
     for name in removal: del kwargs[name]
 
-def verify(condition, message = None, code = None):
+def verify(condition, message = None, code = None, exception = None):
     if condition: return
-    raise exceptions.AssertionError(
-        message = message,
-        code = code
-    )
+    exception = exception or exceptions.AssertionError
+    kwargs = dict()
+    if not message == None: kwargs["message"] = message
+    if not code == None: kwargs["code"] = code
+    raise exception(**kwargs)
 
 def execute(args, command = None, path = None, shell = None, encoding = None):
     if shell == None: shell = os.name == "nt"
